import{f as o,v as n,w as i}from"./index-acc71b99.js";const a=o=>n("./wizard",{method:"post",body:JSON.stringify(o)}),t=n=>o(`./info?configuration=${n}`),e=o=>n(`./delete?configuration=${o}`,{method:"post"}),s=(o,n)=>i("compile",{configuration:o},void 0,n),r=n=>o(`./manifest.json?configuration=${n}`),c=(o,n)=>{let i=`./download.bin?configuration=${encodeURIComponent(o)}`;return n&&(i+="&type=firmware-factory.bin"),i};export{t as a,a as b,s as c,e as d,r as e,c as g};
